@@ -49,9 +49,12 @@ pub fn is_proc_name(s: &str) -> bool {
       // ffi
       | "&ffi-message"
       | "&call-dylib:str->str"
+      | "&call-dylib:str->unit"
       | "&call-dylib:str:str->str"
       | "&call-dylib:str->bool"
-      | "&call-dylib->str"
+      | "&call-dylib:->str"
+      | "&call-dylib:str->vec-str"
+      | "&call-dylib:vec-str->tuple-str2"
       // external format
       | "parse-cirru"
       | "format-cirru"
@@ -228,9 +231,12 @@ pub fn handle_proc(name: &str, args: &CalcitItems) -> Result<Calcit, String> {
     // ffi
     "&ffi-message" => ffi::ffi_message(args),
     "&call-dylib:str->str" => ffi::call_dylib_str_to_str(args),
+    "&call-dylib:str->unit" => ffi::call_dylib_str_to_unit(args),
     "&call-dylib:str:str->str" => ffi::call_dylib_str_str_to_str(args),
     "&call-dylib:str->bool" => ffi::call_dylib_str_to_bool(args),
-    "&call-dylib->str" => ffi::call_dylib_to_str(args),
+    "&call-dylib:->str" => ffi::call_dylib_to_str(args),
+    "&call-dylib:str->vec-str" => ffi::call_dylib_str_to_vec_str(args),
+    "&call-dylib:vec-str->tuple-str2" => ffi::call_dylib_vec_str_to_tuple_str2(args),
     // external data format
     "parse-cirru" => meta::parse_cirru(args),
     "format-cirru" => meta::write_cirru(args),
